.. _report-bugs:

Reporting Bugs and Asking Questions
-----------------------------------

If you think you have encountered a bug in semver or have an idea for a new
feature? Great! We like to hear from you!

There are several options to participate:

* Open a new topic on our `GitHub discussion <gh_discussions>`_ page.
  Tell us our ideas or ask your questions.

* Look into our GitHub `issues`_ tracker or open a new issue.


.. _issues:  https://github.com/python-semver/python-semver/issues
.. _gh_discussions: https://github.com/python-semver/python-semver/discussions
